@@ -145,7 +145,7 @@ gdk_device_wintab_get_state (GdkDevice       *device,
     }
 
   if (device_wintab->last_axis_data)
-    _gdk_device_wintab_translate_axes (device, window, axes, NULL, NULL);
+    _gdk_device_wintab_translate_axes (device_wintab, window, axes, NULL, NULL);
 }
 
 static void
@@ -322,7 +322,7 @@ _gdk_device_wintab_translate_axes (GdkDeviceWintab *device_wintab,
   if (!_gdk_device_wintab_get_window_coords (impl_window, &root_x, &root_y))
     return;
 
-  for (i = 0; i < device->num_axes; i++)
+  for (i = 0; i < gdk_device_get_n_axes (device); i++)
     {
       GdkAxisUse use;
 
@@ -372,7 +372,7 @@ _gdk_input_check_extension_events (GdkDevice *device)
 
   for (l = input_windows; l; l = l->next)
     {
-      GdkWindowObject *window_private;
+      GdkWindow *window_private;
       GdkEventMask event_mask = 0;
 
       window_private = l->data;
